# Copyright 1999-2014. Parallels IP Holdings GmbH. All Rights Reserved.
""" Subprocess handling helpers and compatibility routines. """
import subprocess


def check_output(*popenargs, **kwargs):
    """ Compatibility implementation of subprocess.check_output() introduced in Python 2.7.

        >>> check_output(['/bin/echo', 'hello', 'world'])
        'hello world\\n'
        >>> check_output(['/bin/false'])
        Traceback (most recent call last):
            ...
        CalledProcessError: Command '['/bin/false']' returned non-zero exit status 1
    """
    if 'stdout' in kwargs:
        raise ValueError("stdout argument is not allowed")

    process = subprocess.Popen(stdout=subprocess.PIPE, *popenargs, **kwargs)
    stdout, stderr = process.communicate()
    retcode = process.poll()
    if retcode:
        cmd = kwargs.get('args')
        if cmd is None:
            cmd = popenargs[0]
        raise subprocess.CalledProcessError(retcode, cmd)

    return stdout


if __name__ == '__main__':
    import doctest
    import sys

    sys.exit( doctest.testmod().failed )

# vim: ts=4 sts=4 sw=4 et :
